.. _pfb:

*********************************************
Polyphase Filter Banks (`baseband_tasks.pfb`)
*********************************************

`~baseband_tasks.pfb` contains tasks for applying polyphase filter banks,
as well as undoing their effect.

.. _pfb_api:

Reference/API
=============

.. automodapi:: baseband_tasks.pfb
   :no-inherited-members:
